@@ -9,11 +9,8 @@ import jax.scipy.stats as stats
 import numpy as np
 from absl.testing import absltest, parameterized
 
+import blackjax
 import blackjax.diagnostics as diagnostics
-import blackjax.hmc as hmc
-import blackjax.nuts as nuts
-import blackjax.rmh as rmh
-import blackjax.stan_warmup as stan_warmup
 
 
 def inference_loop(kernel, num_samples, rng_key, initial_state):
@@ -27,16 +24,27 @@ def inference_loop(kernel, num_samples, rng_key, initial_state):
     return states
 
 
+def orbit_samples(orbits, weights, rng_key):
+    def sample_orbit(orbit, weights, rng_key):
+        sample = jax.random.choice(rng_key, orbit, p=weights)
+        return sample
+
+    keys = jax.random.split(rng_key, orbits.shape[0])
+    samples = jax.vmap(sample_orbit)(orbits, weights, keys)
+
+    return samples
+
+
 regresion_test_cases = [
     {
-        "algorithm": hmc,
+        "algorithm": blackjax.hmc,
         "initial_position": {"scale": 1.0, "coefs": 2.0},
         "parameters": {"num_integration_steps": 90},
         "num_warmup_steps": 3_000,
         "num_sampling_steps": 2_000,
     },
     {
-        "algorithm": nuts,
+        "algorithm": blackjax.nuts,
         "initial_position": {"scale": 1.0, "coefs": 2.0},
         "parameters": {},
         "num_warmup_steps": 1_000,
@@ -61,7 +69,6 @@ class LinearRegressionTest(chex.TestCase):
         logpdf += stats.norm.logpdf(preds, y, scale)
         return jnp.sum(logpdf)
 
-    @chex.all_variants(with_pmap=False)
     @parameterized.parameters(itertools.product(regresion_test_cases, [True, False]))
     def test_linear_regression(self, case, is_mass_matrix_diagonal):
         """Test the HMC kernel and the Stan warmup."""
@@ -75,32 +82,22 @@ class LinearRegressionTest(chex.TestCase):
         logposterior_fn = lambda x: logposterior_fn_(**x)
 
         warmup_key, inference_key = jax.random.split(rng_key, 2)
-        initial_position = case["initial_position"]
-        initial_state = case["algorithm"].new_state(initial_position, logposterior_fn)
 
-        def kernel_factory(step_size, inverse_mass_matrix):
-            return case["algorithm"].kernel(
-                logposterior_fn, step_size, inverse_mass_matrix, **case["parameters"]
-            )
-
-        warmup_run = functools.partial(
-            stan_warmup.run,
-            kernel_factory=kernel_factory,
-            num_steps=case["num_warmup_steps"],
-            is_mass_matrix_diagonal=is_mass_matrix_diagonal,
+        warmup = blackjax.window_adaptation(
+            case["algorithm"],
+            logposterior_fn,
+            case["num_warmup_steps"],
+            is_mass_matrix_diagonal,
+            progress_bar=True,
+            **case["parameters"],
         )
-        state, (step_size, inverse_mass_matrix), _ = self.variant(warmup_run)(
-            warmup_key, initial_state=initial_state
+        state, kernel, _ = warmup.run(
+            warmup_key,
+            case["initial_position"],
         )
 
-        if is_mass_matrix_diagonal:
-            assert inverse_mass_matrix.ndim == 1
-        else:
-            assert inverse_mass_matrix.ndim == 2
-
-        kernel = kernel_factory(step_size, inverse_mass_matrix)
         states = inference_loop(
-            kernel, case["num_sampling_steps"], inference_key, initial_state
+            kernel, case["num_sampling_steps"], inference_key, state
         )
 
         coefs_samples = states.position["coefs"]
@@ -112,7 +109,7 @@ class LinearRegressionTest(chex.TestCase):
 
 normal_test_cases = [
     {
-        "algorithm": hmc,
+        "algorithm": blackjax.hmc,
         "initial_position": jnp.array(100.0),
         "parameters": {
             "step_size": 0.1,
@@ -123,19 +120,37 @@ normal_test_cases = [
         "burnin": 5_000,
     },
     {
-        "algorithm": nuts,
+        "algorithm": blackjax.nuts,
         "initial_position": jnp.array(100.0),
         "parameters": {"step_size": 0.1, "inverse_mass_matrix": jnp.array([0.1])},
         "num_sampling_steps": 6000,
         "burnin": 5_000,
     },
     {
-        "algorithm": rmh,
+        "algorithm": blackjax.orbital_hmc,
+        "initial_position": jnp.array(100.0),
+        "parameters": {
+            "step_size": 0.1,
+            "inverse_mass_matrix": jnp.array([0.1]),
+            "period": 100,
+        },
+        "num_sampling_steps": 20_000,
+        "burnin": 15_000,
+    },
+    {
+        "algorithm": blackjax.rmh,
         "initial_position": 1.0,
         "parameters": {"sigma": jnp.array([1.0])},
         "num_sampling_steps": 20_000,
         "burnin": 5_000,
     },
+    {
+        "algorithm": blackjax.mala,
+        "initial_position": 1.0,
+        "parameters": {"step_size": 1e-1},
+        "num_sampling_steps": 20_000,
+        "burnin": 2_000,
+    },
 ]
 
 
@@ -154,14 +169,21 @@ class UnivariateNormalTest(chex.TestCase):
     def test_univariate_normal(
         self, algorithm, initial_position, parameters, num_sampling_steps, burnin
     ):
-        initial_state = algorithm.new_state(initial_position, self.normal_logprob)
+        algo = algorithm(self.normal_logprob, **parameters)
+        initial_state = algo.init(initial_position)
 
-        kernel = algorithm.kernel(self.normal_logprob, **parameters)
+        kernel = algo.step
         states = self.variant(
             functools.partial(inference_loop, kernel, num_sampling_steps)
         )(self.key, initial_state)
 
-        samples = states.position[burnin:]
+        if algorithm == blackjax.orbital_hmc:
+            _, orbit_key = jax.random.split(self.key)
+            samples = orbit_samples(
+                states.positions[burnin:], states.weights[burnin:], orbit_key
+            )
+        else:
+            samples = states.position[burnin:]
 
         np.testing.assert_allclose(np.mean(samples), 1.0, rtol=1e-1)
         np.testing.assert_allclose(np.var(samples), 4.0, rtol=1e-1)
@@ -169,14 +191,14 @@ class UnivariateNormalTest(chex.TestCase):
 
 mcse_test_cases = [
     {
-        "algorithm": hmc,
+        "algorithm": blackjax.hmc,
         "parameters": {
             "step_size": 0.1,
             "num_integration_steps": 32,
         },
     },
     {
-        "algorithm": nuts,
+        "algorithm": blackjax.nuts,
         "parameters": {"step_size": 0.07},
     },
 ]
@@ -187,7 +209,7 @@ class MonteCarloStandardErrorTest(chex.TestCase):
 
     def setUp(self):
         super().setUp()
-        self.key = jax.random.PRNGKey(2351235)
+        self.key = jax.random.PRNGKey(20220203)
 
     def generate_multivariate_target(self, rng=None):
         """Genrate a Multivariate Normal distribution as target."""
@@ -201,7 +223,7 @@ class MonteCarloStandardErrorTest(chex.TestCase):
             scale = jnp.abs(jax.random.normal(scale_rng, [2])) * 2.5
             rho = jax.random.uniform(rho_rng, [], minval=-1.0, maxval=1.0)
 
-        cov = jnp.diag(scale ** 2)
+        cov = jnp.diag(scale**2)
         cov = cov.at[0, 1].set(rho * scale[0] * scale[1])
         cov = cov.at[1, 0].set(rho * scale[0] * scale[1])
 
@@ -212,7 +234,7 @@ class MonteCarloStandardErrorTest(chex.TestCase):
 
     def mcse_test(self, samples, true_param, p_val=0.01):
         posterior_mean = jnp.mean(samples, axis=[0, 1])
-        ess = diagnostics.effective_sample_size(samples, chain_axis=1, sample_axis=0)
+        ess = diagnostics.effective_sample_size(samples, chain_axis=0, sample_axis=1)
         posterior_sd = jnp.std(samples, axis=0, ddof=1)
         avg_monte_carlo_standard_error = jnp.mean(posterior_sd, axis=0) / jnp.sqrt(ess)
         scaled_error = (
@@ -230,22 +252,18 @@ class MonteCarloStandardErrorTest(chex.TestCase):
         )
         num_chains = 10
         initial_positions = jax.random.normal(pos_init_key, [num_chains, 2])
-        kernel = algorithm.kernel(
-            logprob_fn, inverse_mass_matrix=true_scale, **parameters
-        )
-        initial_states = jax.vmap(algorithm.new_state, in_axes=(0, None))(
-            initial_positions, logprob_fn
-        )
+        kernel = algorithm(logprob_fn, inverse_mass_matrix=true_scale, **parameters)
+        initial_states = jax.vmap(kernel.init, in_axes=(0,))(initial_positions)
         multi_chain_sample_key = jax.random.split(sample_key, num_chains)
 
         inference_loop_multiple_chains = jax.vmap(
-            functools.partial(inference_loop, kernel, 2_000)
+            functools.partial(inference_loop, kernel.step, 2_000)
         )
         states = inference_loop_multiple_chains(multi_chain_sample_key, initial_states)
 
-        posterior_samples = states.position[-1000:]
+        posterior_samples = states.position[:, -1000:]
         posterior_delta = posterior_samples - true_loc
-        posterior_variance = posterior_delta ** 2.0
+        posterior_variance = posterior_delta**2.0
         posterior_correlation = jnp.prod(posterior_delta, axis=-1, keepdims=True) / (
             true_scale[0] * true_scale[1]
         )
@@ -253,7 +271,7 @@ class MonteCarloStandardErrorTest(chex.TestCase):
         _ = jax.tree_multimap(
             self.mcse_test,
             [posterior_samples, posterior_variance, posterior_correlation],
-            [true_loc, true_scale ** 2, true_rho],
+            [true_loc, true_scale**2, true_rho],
         )
 
 
