@@ -7,11 +7,11 @@ import jax.numpy as jnp
 import numpy as np
 from absl.testing import absltest, parameterized
 
-import blackjax.inference.hmc.integrators as integrators
-import blackjax.inference.hmc.metrics as metrics
-import blackjax.inference.hmc.proposal as proposal
-import blackjax.inference.hmc.termination as termination
-import blackjax.inference.hmc.trajectory as trajectory
+import blackjax.mcmc.integrators as integrators
+import blackjax.mcmc.metrics as metrics
+import blackjax.mcmc.proposal as proposal
+import blackjax.mcmc.termination as termination
+import blackjax.mcmc.trajectory as trajectory
 
 divergence_threshold = 1000
 
@@ -157,7 +157,7 @@ class TrajectoryTest(chex.TestCase):
                 initial_state,
                 direction,
                 termination_state,
-                2 ** tree_depth,
+                2**tree_depth,
                 step_size,
                 initial_energy,
             )
@@ -206,7 +206,7 @@ class TrajectoryTest(chex.TestCase):
         rng_key = jax.random.PRNGKey(0)
 
         def potential_fn(x):
-            return 0.5 * x ** 2
+            return 0.5 * x**2
 
         position = 0.0
         inverse_mass_matrix = jnp.array([1.0])
@@ -233,7 +233,7 @@ class TrajectoryTest(chex.TestCase):
         )
 
         expand = trajectory.dynamic_multiplicative_expansion(
-            trajectory_integrator, uturn_check_fn, step_size
+            trajectory_integrator, uturn_check_fn
         )
 
         state = integrators.new_integrator_state(
@@ -253,7 +253,7 @@ class TrajectoryTest(chex.TestCase):
         )
 
         expansion_state, (is_diverging, is_turning) = self.variant(expand)(
-            rng_key, initial_expansion_state, energy
+            rng_key, initial_expansion_state, energy, step_size
         )
 
         assert is_diverging == should_diverge
